==> gradle-1.11-rc-1-all.zip: gradle-1.11-rc-1/src/core-impl/org/gradle/api/internal/artifacts/ivyservice/SubstitutedModuleVersionIdResolveResult.java <==
/*
 * Copyright 2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.artifacts.ivyservice;

import org.gradle.api.artifacts.ModuleVersionIdentifier;
import org.gradle.api.artifacts.result.ComponentSelectionReason;

class SubstitutedModuleVersionIdResolveResult implements ModuleVersionIdResolveResult {

    final ModuleVersionIdResolveResult result;
    private final ComponentSelectionReason selectionReason;

    public SubstitutedModuleVersionIdResolveResult(ModuleVersionIdResolveResult result, ComponentSelectionReason selectionReason) {
        this.result = result;
        this.selectionReason = selectionReason;
    }

    public ModuleVersionResolveException getFailure() {
        return result.getFailure();
    }

    public ModuleVersionIdentifier getId() throws ModuleVersionResolveException {
        return result.getId();
    }

    public ModuleVersionResolveResult resolve() {
        return result.resolve();
    }

    public ComponentSelectionReason getSelectionReason() {
        return selectionReason;
    }
}

==> gradle-2.1-rc-3-all.zip: gradle-2.1-rc-3/src/core-impl/org/gradle/api/internal/artifacts/ivyservice/SubstitutedModuleVersionIdResolveResult.java <==
/*
 * Copyright 2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.artifacts.ivyservice;

import org.gradle.api.artifacts.ModuleIdentifier;
import org.gradle.api.artifacts.ModuleVersionIdentifier;
import org.gradle.api.artifacts.result.ComponentSelectionReason;

class SubstitutedModuleVersionIdResolveResult implements ModuleVersionIdResolveResult {

    final ModuleVersionIdResolveResult result;
    private final ComponentSelectionReason selectionReason;
    private final ModuleIdentifier preferredTarget;

    public SubstitutedModuleVersionIdResolveResult(ModuleVersionIdResolveResult result, ComponentSelectionReason selectionReason, ModuleIdentifier preferredTarget) {
        this.result = result;
        this.selectionReason = selectionReason;
        this.preferredTarget = preferredTarget;
    }

    public ModuleVersionResolveException getFailure() {
        return result.getFailure();
    }

    public ModuleVersionIdentifier getId() throws ModuleVersionResolveException {
        return result.getId();
    }

    public ComponentResolveResult resolve() {
        return result.resolve();
    }

    public ComponentSelectionReason getSelectionReason() {
        return selectionReason;
    }

    public ModuleIdentifier getPreferredTarget() {
        return preferredTarget;
    }
}
